# OpenRPA
Pixel based automation library

<pre>
channels:
  - conda-forge
  - pytorch
  - fcakyon
dependencies:
  - python=3.7.5
  - python-mss=6.1.0
  - numpy=1.20.1
  - craft-text-detector=0.3.3
  - tesseract=4.1.1
  - pytesseract=0.3.7
  - opencv=4.5.1
  - regex=2020.11.13
  - pynput=1.7.1
  - pyobjc-core=6.2.2
</pre>